changeset 886:0736230c7d91 beta

#92 removed content of binary files for whoosh indexer
author Marcin Kuzminski <marcin@python-works.com>
date Wed, 29 Dec 2010 01:18:13 +0100
parents 94f7585af8a1
children 3c0cae9b58cf
files rhodecode/lib/indexers/daemon.py
diffstat 1 files changed, 2 insertions(+), 2 deletions(-) [+]
line wrap: on
line diff
--- a/rhodecode/lib/indexers/daemon.py	Tue Dec 28 18:44:32 2010 +0100
+++ b/rhodecode/lib/indexers/daemon.py	Wed Dec 29 01:18:13 2010 +0100
@@ -120,8 +120,8 @@
         the instance of vcs backend"""
         node = self.get_node(repo, path)
 
-        #we just index the content of chosen files
-        if node.extension in INDEX_EXTENSIONS:
+        #we just index the content of chosen files, and skip binary files
+        if node.extension in INDEX_EXTENSIONS and not node.is_binary:
 
             u_content = node.content
             if not isinstance(u_content, unicode):